@@ -163,6 +163,8 @@ class Aggregator(object):
 
         feed.save()
 
+        self.post_process_feed(feed, parsed_data)
+
         return updated
 
     # Process a feed entry, creating or updating the entry information
@@ -363,6 +365,16 @@ class Aggregator(object):
             date_modified = date_modified or post.date_modified, author = author,
             author_email = author_email, comments_url = comments_url, feed_id = feed.feed_id)
 
+    # Hook to post-process the feed after it has been checked
+    #
+    # Default implementation finds methods prefixed with process_feed_
+    # and executes these after a feed has been checked
+    def post_process_feed(self, feed, parsed_data):
+        funcnames = [a for a in dir(self) if a.startswith('process_feed_')]
+        for funcname in funcnames:
+            func = getattr(self, funcname)
+            func(feed, parsed_data)
+
     # Hook to post-process the entry after it has been created or
     # modify.
     #
